Learn R Programming

gghinton (version 0.1.0)

gghinton-package: gghinton: Hinton Diagrams for 'ggplot2'

Description

Provides a 'ggplot2' extension for drawing Hinton diagrams, a visualisation technique for numerical matrices in which the area of each square is proportional to the magnitude of the corresponding entry. For signed data, white squares indicate positive values and black squares indicate negative values on a grey background. Hinton diagrams are especially useful for visualising PCA weight matrices, correlation matrices, and transition matrices.

Arguments

Author

Maintainer: Robin Foster gghinton@proton.me [copyright holder]

See Also